/******************************************************************************
 JXToolBarEditWidget.h

	Interface for the JXToolBarEditWidget class

	Copyright © 1997 by Glenn W. Bach.  All rights reserved.
	
	Base code generated by Codemill v0.1.0

 *****************************************************************************/

#ifndef _H_JXToolBarEditWidget
#define _H_JXToolBarEditWidget

#include <JXNamedTreeListWidget.h>

#include <JFileArray.h>

class JNamedTreeList;
class JTree;
class JNamedTreeNode;
class JXImage;

class JXToolBarEditWidget : public JXNamedTreeListWidget
{
public:

	static JXToolBarEditWidget* Create(JNamedTreeList* treeList, 
		JXScrollbarSet* scrollbarSet, JXContainer* enclosure,
		const HSizingOption hSizing, const VSizingOption vSizing,
		const JCoordinate x, const JCoordinate y,
		const JCoordinate w, const JCoordinate h);
	virtual ~JXToolBarEditWidget();

protected:

	JXToolBarEditWidget(JNamedTreeList* treeList, 
		JXScrollbarSet* scrollbarSet, JXContainer* enclosure,
		const HSizingOption hSizing, const VSizingOption vSizing,
		const JCoordinate x, const JCoordinate y,
		const JCoordinate w, const JCoordinate h);

	virtual JBoolean	GetImage(const JIndex index, const JXImage** image) const;
	virtual void 		HandleMouseDown(const JPoint& pt, 
								const JXMouseButton button,
								const JSize clickCount,
						 		const JXButtonStates& buttonStates,
								const JXKeyModifiers& modifiers);

private:

	JXImage*	itsMenuImage;
	JXImage*	itsCheckedItemImage;
	JXImage*	itsUncheckedItemImage;

private:

	// not allowed

	JXToolBarEditWidget(const JXToolBarEditWidget& source);
	const JXToolBarEditWidget& operator=(const JXToolBarEditWidget& source);

};

#endif
