/******************************************************************************
 JToolBarLibVersion.h

	Defines current version of the JToolBar library

	Copyright © 1999 by Glenn W. Bach. All rights reserved.

 ******************************************************************************/

#ifndef _H_JToolBarLibVersion
#define _H_JToolBarLibVersion

// These have to be #defined so they can be used for conditional compilation.

#define CURRENT_JTOOLBAR_MAJOR_VERSION	0
#define CURRENT_JTOOLBAR_MINOR_VERSION	5
#define CURRENT_JTOOLBAR_PATCH_VERSION	4

// This is mainly provided so programmers can see the official version number.

static const char* kCurrentJToolBarLibVersionStr = "0.5.4";

// version 0.5.2:
//	Added documentation in header of JXToolBar.cc.
//	JXToolBarEditDir:
//		BuildWindow() now sets the window's title.

// version 0.5.1:
//	JXToolBar:
//		Fixed bug so it is safe for a button in the toolbar to delete the window.
//			(e.g. the standard Close item on the File menu)

// version 0.5.0:
//	JXToolBar:
//		Fixed a geometry bug.
//		Added another AppendButton() function - this one takes an id instead of
//			a index.
//		Renamed GetToolBarEnclosure() to GetWidgetEnclosure().
//		Renamed AdjustButtonSize() to UseSmallButtons().
//		Renamed SetType() to SetButtonType().
//		Added IsUsingSmallButtons(), ToolBarVisible(), and GetButtonType().
//		Now checks for button changes periodically (ie. size/font/style).
//		Changed the constructor, adding minWidth and minHeight. These are
//			the minimum width and height for the window minus the toolbar. 
//			The toolbar now automatically adjusts the window's minsize
//			based on its own size.
//		Added Get/SetWindowMinSize().
//	JXToolBarButton:
//		Added NeedsGeometryAdjustment() that checks to see if the button 
//			needs to resize. It does the resize if necessary and returns
//			whether or not it resized. The font name/size/style are also 
//			updated here.

#endif
